scipy.odr.odrpack
=================

.. automodule:: scipy.odr.odrpack

   
   
   .. rubric:: Functions

   .. autosummary::
   
      odr
      report_error
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Data
      Model
      ODR
      Output
      RealData
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
   
      odr_error
      odr_stop
   
   